Welcome to the documentation for GWPopulation!
==============================================

.. currentmodule:: gwpopulation

.. automodule:: gwpopulation
    :members:

API:
----

.. autosummary::
   :toctree: _autosummary
   :template: custom-module-template.rst
   :caption: API:
   :recursive:

   models
   conversions
   cupy_utils
   hyperpe
   utils
   vt

.. toctree::
   :maxdepth: 1
   :caption: Examples:

   GWTC1
